==> swc-1.3.97.tar.gz: swc-1.3.97/crates/swc_ecma_transforms_proposal/tests/decorators/2022-03-ordering/initializers/output.js <==
var _dec, _dec1, _initClass, _dec2, _dec3, _dec4, _dec5, _dec6, _dec7, _dec8, _dec9, _dec10, _dec11, _dec12, _dec13, _dec14, _dec15, _dec16, _dec17, _call_c, _call_d, _init_e, _init_f, _init_g, _get___g, _set___g, _init_h, _get___h, _set___h, _initProto, _initStatic;
let _A;
_dec = logDecoratorRun(0, 35, 45), _dec1 = logDecoratorRun(1, 34, 44), _dec2 = logDecoratorRun(2, 27, 47), _dec3 = logDecoratorRun(3, 26, 46), _dec4 = logDecoratorRun(4, 19, 37), _dec5 = logDecoratorRun(5, 18, 36), _dec6 = logDecoratorRun(6, 21, 39), _dec7 = logDecoratorRun(7, 20, 38), _dec8 = logDecoratorRun(8, 29, 49), _dec9 = logDecoratorRun(9, 28, 48), _dec10 = logDecoratorRun(10, 31, 51), _dec11 = logDecoratorRun(11, 30, 50), _dec12 = logDecoratorRun(12, 23, 41), _dec13 = logDecoratorRun(13, 22, 40), _dec14 = logDecoratorRun(14, 25, 43), _dec15 = logDecoratorRun(15, 24, 42), _dec16 = logDecoratorRun(16, 33, 53), _dec17 = logDecoratorRun(17, 32, 52);
new class extends _identity {
    constructor(){
        super(_A), _initClass();
    }
    static{
        class A {
            static{
                ({ e: [_call_c, _init_f, _init_g, _get___g, _set___g, _call_d, _init_e, _init_h, _get___h, _set___h, _initProto, _initStatic], c: [_A, _initClass] } = _apply_decs_2203_r(this, [
                    [
                        [
                            _dec4,
                            _dec5
                        ],
                        7,
                        "b"
                    ],
                    [
                        [
                            _dec6,
                            _dec7
                        ],
                        7,
                        "c",
                        function() {}
                    ],
                    [
                        [
                            _dec12,
                            _dec13
                        ],
                        6,
                        "f"
                    ],
                    [
                        [
                            _dec14,
                            _dec15
                        ],
                        6,
                        "g",
                        function() {
                            return this.#__g;
                        },
                        function(_v) {
                            this.#__g = _v;
                        }
                    ],
                    [
                        [
                            _dec2,
                            _dec3
                        ],
                        2,
                        "a"
                    ],
                    [
                        [
                            _dec8,
                            _dec9
                        ],
                        2,
                        "d",
                        function() {}
                    ],
                    [
                        [
                            _dec10,
                            _dec11
                        ],
                        1,
                        "e"
                    ],
                    [
                        [
                            _dec16,
                            _dec17
                        ],
                        1,
                        "h",
                        function() {
                            return this.#__h;
                        },
                        function(_v) {
                            this.#__h = _v;
                        }
                    ]
                ], [
                    _dec,
                    _dec1
                ]));
                _initStatic(this);
            }
            a() {}
            static b() {}
            get #d() {
                return _call_d;
            }
            #___private_e = (_initProto(this), _init_e(this));
            get e() {
                return this.#___private_e;
            }
            set e(_v) {
                this.#___private_e = _v;
            }
            static get f() {
                return this.#___private_f;
            }
            static set f(_v) {
                this.#___private_f = _v;
            }
            #__h = _init_h(this);
            get #h() {
                return _get___h(this);
            }
            set #h(_v) {
                _set___h(this, _v);
            }
        }
    }
    get #c() {
        return _call_c;
    }
    #___private_f = _init_f(this);
    #__g = _init_g(this);
    get #g() {
        return _get___g(this);
    }
    set #g(_v) {
        _set___g(this, _v);
    }
}();

==> swc-1.11.22.tar.gz: swc-1.11.22/crates/swc_ecma_transforms_proposal/tests/decorators/2022-03-ordering/initializers/output.js <==
var _dec, _dec1, _initClass, _dec2, _dec3, _dec4, _dec5, _dec6, _dec7, _dec8, _dec9, _dec10, _dec11, _dec12, _dec13, _dec14, _dec15, _dec16, _dec17, _call_c, _call_d, _init_e, _init_f, _init_g, _get___g, _set___g, _init_h, _get___h, _set___h, _initProto, _initStatic;
let _A;
_dec = logDecoratorRun(0, 35, 45), _dec1 = logDecoratorRun(1, 34, 44), _dec2 = logDecoratorRun(2, 27, 47), _dec3 = logDecoratorRun(3, 26, 46), _dec4 = logDecoratorRun(4, 19, 37), _dec5 = logDecoratorRun(5, 18, 36), _dec6 = logDecoratorRun(6, 21, 39), _dec7 = logDecoratorRun(7, 20, 38), _dec8 = logDecoratorRun(8, 29, 49), _dec9 = logDecoratorRun(9, 28, 48), _dec10 = logDecoratorRun(10, 31, 51), _dec11 = logDecoratorRun(11, 30, 50), _dec12 = logDecoratorRun(12, 23, 41), _dec13 = logDecoratorRun(13, 22, 40), _dec14 = logDecoratorRun(14, 25, 43), _dec15 = logDecoratorRun(15, 24, 42), _dec16 = logDecoratorRun(16, 33, 53), _dec17 = logDecoratorRun(17, 32, 52);
new class extends _identity {
    constructor(){
        super(_A), _initClass();
    }
    static{
        class A {
            static{
                ({ e: [_call_c, _init_f, _init_g, _get___g, _set___g, _call_d, _init_e, _init_h, _get___h, _set___h, _initProto, _initStatic], c: [_A, _initClass] } = _apply_decs_2203_r(this, [
                    [
                        [
                            _dec4,
                            _dec5
                        ],
                        7,
                        "b"
                    ],
                    [
                        [
                            _dec6,
                            _dec7
                        ],
                        7,
                        "c",
                        function() {}
                    ],
                    [
                        [
                            _dec12,
                            _dec13
                        ],
                        6,
                        "f"
                    ],
                    [
                        [
                            _dec14,
                            _dec15
                        ],
                        6,
                        "g",
                        function() {
                            return this.#__g_3;
                        },
                        function(_v) {
                            this.#__g_3 = _v;
                        }
                    ],
                    [
                        [
                            _dec2,
                            _dec3
                        ],
                        2,
                        "a"
                    ],
                    [
                        [
                            _dec8,
                            _dec9
                        ],
                        2,
                        "d",
                        function() {}
                    ],
                    [
                        [
                            _dec10,
                            _dec11
                        ],
                        1,
                        "e"
                    ],
                    [
                        [
                            _dec16,
                            _dec17
                        ],
                        1,
                        "h",
                        function() {
                            return this.#__h_4;
                        },
                        function(_v) {
                            this.#__h_4 = _v;
                        }
                    ]
                ], [
                    _dec,
                    _dec1
                ]));
                _initStatic(this);
            }
            a() {}
            static b() {}
            get #d() {
                return _call_d;
            }
            #___private_e_1 = (_initProto(this), _init_e(this));
            get e() {
                return this.#___private_e_1;
            }
            set e(_v) {
                this.#___private_e_1 = _v;
            }
            static get f() {
                return this.#___private_f_2;
            }
            static set f(_v) {
                this.#___private_f_2 = _v;
            }
            #__h_4 = _init_h(this);
            get #h() {
                return _get___h(this);
            }
            set #h(_v) {
                _set___h(this, _v);
            }
        }
    }
    get #c() {
        return _call_c;
    }
    #___private_f_2 = _init_f(this);
    #__g_3 = _init_g(this);
    get #g() {
        return _get___g(this);
    }
    set #g(_v) {
        _set___g(this, _v);
    }
}();
